==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Bidali");
define("_URL","URL");
define("_PRINTER","Inprimatzeko bertsioa");
define("_FRIEND","Lagun bati bidali");



define("_YOURNAME","Zure izena");

define("_OK","Bidali");
define("_RELATED","Erlazionaturik");
define("_MOREABOUT","Gehiago honetaz:");
define("_NEWSBY","Noren Notiziak:");
define("_MOSTREAD","Gehien irakurri den artikuloa atal honetan:");
define("_READMORE","Gehiago irakurri...");
define("_BYTESMORE","byte gehien");
define("_COMMENTSQ","komentariorik?");
define("_COMMENT","komentarioa");

define("_CONFIGURE","Konfiguratu");
define("_LOGINCREATE","Zure Kontura sartu");
define("_THRESHOLD","Puntuak");
define("_NOCOMMENTS","Komentariorik gabe");
define("_NESTED","Gaika lotu");
define("_FLAT","Sartu diren ordenean");
define("_THREAD","Hariagatik");
define("_OLDEST","Zaharrak lehenago");
define("_NEWEST","Berriak lehenago");
define("_HIGHEST","Puntuazio gehien daukatenek lehenago");
define("_COMMENTSWARNING","Bidalitako komentarioak bakoitzaren errespontsabilitatea izango dira, inola ere Sistemako arduradunarenak.");
define("_SCORE","Puntuazioa");


define("_USERINFO","Erabiltzailearen informazioa");
define("_READREST","Komentario guztia irakurri...");
define("_REPLY","Honi erantzun");
define("_REPLYMAIN","Komentarioa bidali");
define("_NOSUBJECT","Gairik gabe");
define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"user.php\">erregstratu</a> zaitez");
define("_PARENT","Aurrekoa");
define("_ROOT","Erroa/Lehena");

define("_UCOMMENT","Komentarioa");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_EXTRANS","Itzuli (html tag-ak testu bihurtu)");
define("_HTMLFORMATED","HTML formatoakin");
define("_PLAINTEXT","Testu laua bakarrik");
define("_ONN","non...");
define("_SUBJECT","Gaia");
define("_COMMENTREPLY","Komentarioa bidali");
define("_COMREPLYPRE","Komentarioen aurrebista");
define("_NOTRIGHT","Zeozer ez doia ondo. abisatu sistemako arduradunari. just to keep things from messing up down the road");
define("_SENDAMSG","Mezu bat bidali");
define("_YOUSENDSTORY","Notizi hau:");
define("_TOAFRIEND","lagun bati bidali:");
define("_FYOURNAME","Zure izena:");
define("_FYOUREMAIL","Zure emaila:");
define("_FFRIENDNAME","Lagunaren izena:");
define("_FFRIENDEMAIL","Lagunaren emaila:");
define("_INTERESTING","Berri interesgarria sistema honetan:");
define("_HELLO","Kaixo");
define("_YOURFRIEND","Zure laguna den honek:");
define("_CONSIDERED",", bidali egin nahi izan dizu berri hau interesgarria iruditu zaiolako.");
define("_FDATE","Data");
define("_FTOPIC","Gaia");
define("_YOUCANREAD","Berri interesgarri gehiago irakurri ditzakezu sistema honetan:");
define("_FSTORY","Notizi hau:");
define("_HASSENT","zure lagun honi bidali zaio:");
define("_THANKS","eskerrikasko!");
define("_RECOMMEND","Tokia lagun bati gomendatu");
define("_PDATE","Data");
define("_PTOPIC","Gaia");
define("_COMESFROM","Notizi hau aterata dagoen sistemaren izena:");
define("_THEURL","Notiziaren URLa:");





define("_PREVIEW","Aurrebista");
define("_NEWUSER","Usuario berria sortu");
define("_OPTIONS","Aukerak");


define("_REFRESH","Birkargatu");
define("_ADD","gehitu");
define("_NOCOMMENTSACT","Senitzen dut, komentarioak ez daude erabilgarri artikulo honetan");
define("_ARTICLEPOLL","Artikuloaren inkesta");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Bidali");
define("_URL","URL");
define("_PRINTER","Inprimatzeko bertsioa");
define("_FRIEND","Lagun bati bidali");



define("_YOURNAME","Zure izena");

define("_OK","Bidali");
define("_RELATED","Erlazionaturik");
define("_MOREABOUT","Gehiago honetaz:");
define("_NEWSBY","Noren Notiziak:");
define("_MOSTREAD","Gehien irakurri den artikuloa atal honetan:");
define("_READMORE","Gehiago irakurri...");
define("_BYTESMORE","byte gehien");
define("_COMMENTSQ","komentariorik?");
define("_COMMENT","komentarioa");

define("_CONFIGURE","Konfiguratu");
define("_LOGINCREATE","Zure Kontura sartu");
define("_THRESHOLD","Puntuak");
define("_NOCOMMENTS","Komentariorik gabe");
define("_NESTED","Gaika lotu");
define("_FLAT","Sartu diren ordenean");
define("_THREAD","Hariagatik");
define("_OLDEST","Zaharrak lehenago");
define("_NEWEST","Berriak lehenago");
define("_HIGHEST","Puntuazio gehien daukatenek lehenago");
define("_COMMENTSWARNING","Bidalitako komentarioak bakoitzaren errespontsabilitatea izango dira, inola ere Sistemako arduradunarenak.");
define("_SCORE","Puntuazioa");


define("_USERINFO","Erabiltzailearen informazioa");
define("_READREST","Komentario guztia irakurri...");
define("_REPLY","Honi erantzun");
define("_REPLYMAIN","Komentarioa bidali");
define("_NOSUBJECT","Gairik gabe");
define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"user.php\">erregstratu</a> zaitez");
define("_PARENT","Aurrekoa");
define("_ROOT","Erroa/Lehena");

define("_UCOMMENT","Komentarioa");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_EXTRANS","Itzuli (html tag-ak testu bihurtu)");
define("_HTMLFORMATED","HTML formatoakin");
define("_PLAINTEXT","Testu laua bakarrik");
define("_ONN","non...");
define("_SUBJECT","Gaia");
define("_COMMENTREPLY","Komentarioa bidali");
define("_COMREPLYPRE","Komentarioen aurrebista");
define("_NOTRIGHT","Zeozer ez doia ondo. abisatu sistemako arduradunari. just to keep things from messing up down the road");
define("_SENDAMSG","Mezu bat bidali");
define("_YOUSENDSTORY","Notizi hau:");
define("_TOAFRIEND","lagun bati bidali:");
define("_FYOURNAME","Zure izena:");
define("_FYOUREMAIL","Zure emaila:");
define("_FFRIENDNAME","Lagunaren izena:");
define("_FFRIENDEMAIL","Lagunaren emaila:");
define("_INTERESTING","Berri interesgarria sistema honetan:");
define("_HELLO","Kaixo");
define("_YOURFRIEND","Zure laguna den honek:");
define("_CONSIDERED",", bidali egin nahi izan dizu berri hau interesgarria iruditu zaiolako.");
define("_FDATE","Data");
define("_FTOPIC","Gaia");
define("_YOUCANREAD","Berri interesgarri gehiago irakurri ditzakezu sistema honetan:");
define("_FSTORY","Notizi hau:");
define("_HASSENT","zure lagun honi bidali zaio:");
define("_THANKS","eskerrikasko!");
define("_RECOMMEND","Tokia lagun bati gomendatu");
define("_PDATE","Data");
define("_PTOPIC","Gaia");
define("_COMESFROM","Notizi hau aterata dagoen sistemaren izena:");
define("_THEURL","Notiziaren URLa:");





define("_PREVIEW","Aurrebista");
define("_NEWUSER","Usuario berria sortu");
define("_OPTIONS","Aukerak");


define("_REFRESH","Birkargatu");
define("_ADD","gehitu");
define("_NOCOMMENTSACT","Senitzen dut, komentarioak ez daude erabilgarri artikulo honetan");
define("_ARTICLEPOLL","Artikuloaren inkesta");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
